@@ -12,7 +12,7 @@ use Compress::Zlib();
 use JSON();
 use overload '""' => 'string';
 
-our $VERSION = '0.11';
+our $VERSION = 0.12;
 
 sub new {
     my ( $class, $params ) = @_;
@@ -40,8 +40,12 @@ sub gzip {
 
 sub string {
     my ( $self, $string ) = @_;
-    my $old =
-      JSON->new()->utf8()->allow_blessed(1)->convert_blessed(1)->pretty()->encode($self);
+    my $json = JSON->new();
+    $json = $json->utf8();
+    $json = $json->allow_blessed(1);
+    $json = $json->convert_blessed(1);
+    $json = $json->pretty();
+    my $old = $json->encode($self);
     if ( ( @_ > 1 ) && ( defined $string ) ) {
         $self->_init();
         my $ref = JSON->new()->utf8()->decode($string);
@@ -456,7 +460,9 @@ Archive::Har - Provides an interface to HTTP Archive (HAR) files
 
 =head1 VERSION
 
-Version '0.11'
+Version 0.12
+
+=for stopwords xml gzip stringified HAR gzipped gzipping JSON
 
 =head1 SYNOPSIS
 
@@ -469,21 +475,27 @@ Version '0.11'
     $har->creator()->name("new name"); # update har
     print $har->browser()->name() . ' version ' . $har->browser()->version();
     foreach my $page = $har->pages()) {
-       print "Page Title: " . $page->title() . "\n";
+        $page->comment("Something interesting here");
+        print "Page Title: " . $page->title() . "\n";
 
     }
     print $har; # print har in stringified pretty form
     ...
 
+=head1 DESCRIPTION
+ 
+This Module is intended to provide an interface to create/read/update
+entire HTTP Archive (HAR) files.
+
 =head1 SUBROUTINES/METHODS
 
 =head2 new
 
-Archive::Har->new() will return a new har object, ready to process http archives
+Archive::Har->new() will return a new HAR object, ready to process HTTP archives
 
 =head2 string
 
-$har->string() accepts a stringified version of an L<http archive|http://www.softwareishard.com/blog/har-12-spec/> and parses it.  It returns the previous state of the archive in stringified form
+$har->string() accepts a stringified version of an L<HTTP archive|http://www.softwareishard.com/blog/har-12-spec/> and parses it.  It returns the previous state of the archive in stringified form
 
 =head2 gzip
 
@@ -517,6 +529,39 @@ $har->entries() will return the list of L<entry|Archive::Har::Entry> objects for
 
 $har->comment() will return the comment for the HTTP Archive
 
+=head1 DIAGNOSTICS
+
+=over
+
+=item C<< Failed to gzip HAR archive >>
+
+An error occurred while gzipping.
+
+=back
+
+=head1 CONFIGURATION AND ENVIRONMENT
+
+Archive::Har requires no configuration files or environment variables.  
+
+=head1 DEPENDENCIES
+
+Archive::Har requires the following non-core Perl modules
+
+=over
+
+=item *
+L<JSON|JSON>
+=item *
+L<Compress::Zlib|Compress::Zlib>
+=item *
+L<XML::LibXML|XML::LibXML>
+
+=back
+
+=head1 INCOMPATIBILITIES
+
+None reported
+
 =head1 SEE ALSO
 
 L<HTTP Archive 1.2 Specification|http://www.softwareishard.com/blog/har-12-spec/>
@@ -525,51 +570,15 @@ L<HTTP Archive 1.2 Specification|http://www.softwareishard.com/blog/har-12-spec/
 
 David Dick, C<< <ddick at cpan.org> >>
 
-=head1 BUGS
+=head1 BUGS AND LIMITATIONS
 
 Please report any bugs or feature requests to C<bug-archive-har at rt.cpan.org>, or through
 the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Archive-Har>.  I will be notified, and then you'll
 automatically be notified of progress on your bug as I make changes.
 
-
-
-
-=head1 SUPPORT
-
-You can find documentation for this module with the perldoc command.
-
-    perldoc Archive::Har
-
-
-You can also look for information at:
-
-=over 4
-
-=item * RT: CPAN's request tracker
-
-L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=Archive-Har>
-
-=item * AnnoCPAN: Annotated CPAN documentation
-
-L<http://annocpan.org/dist/Archive-Har>
-
-=item * CPAN Ratings
-
-L<http://cpanratings.perl.org/d/Archive-Har>
-
-=item * Search CPAN
-
-L<http://search.cpan.org/dist/Archive-Har/>
-
-=back
-
-
-=head1 ACKNOWLEDGEMENTS
-
-
 =head1 LICENSE AND COPYRIGHT
 
-Copyright 2012 David Dick.
+Copyright 2015 David Dick.
 
 This program is free software; you can redistribute it and/or modify it
 under the terms of either: the GNU General Public License as published
