@@ -4,7 +4,7 @@ use warnings;
 use strict;
 use Carp();
 
-our $VERSION = '0.11';
+our $VERSION = 0.12;
 
 sub new {
     my ( $class, $params ) = @_;
@@ -109,7 +109,9 @@ Archive::Har::Browser - Represents the browser that created of the HTTP Archive
 
 =head1 VERSION
 
-Version '0.11'
+Version 0.12
+
+=for stopwords HAR
 
 =head1 SYNOPSIS
 
@@ -122,6 +124,11 @@ Version '0.11'
     print "Version: " . $har->browser()->version() . "\n";
     print "Comment: " . $har->browser()->comment() . "\n";
 
+=head1 DESCRIPTION
+ 
+This Module is intended to provide an interface to create/read/update
+Browser objects in HTTP Archive (HAR) files.
+
 =head1 SUBROUTINES/METHODS
 
 =head2 new
@@ -140,3 +147,48 @@ returns the version of the Browser
 
 returns the comment about the Browser
 
+=head1 DIAGNOSTICS
+
+=over
+
+=item C<< %s is not specified in the HAR 1.2 spec and does not start with an underscore >>
+
+The HAR 1.2 specification allows undocumented fields, but they must start with an underscore
+
+=back
+
+=head1 CONFIGURATION AND ENVIRONMENT
+
+Archive::Har::Browser requires no configuration files or environment variables.  
+
+=head1 DEPENDENCIES
+
+Archive::Har::Browser requires no additional non-core Perl modules
+
+=head1 INCOMPATIBILITIES
+
+None reported
+
+=head1 AUTHOR
+
+David Dick, C<< <ddick at cpan.org> >>
+
+=head1 BUGS AND LIMITATIONS
+
+Please report any bugs or feature requests to C<bug-archive-har at rt.cpan.org>, or through
+the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Archive-Har>.  I will be notified, and then you'll
+automatically be notified of progress on your bug as I make changes.
+
+=head1 LICENSE AND COPYRIGHT
+
+Copyright 2015 David Dick.
+
+This program is free software; you can redistribute it and/or modify it
+under the terms of either: the GNU General Public License as published
+by the Free Software Foundation; or the Artistic License.
+
+See http://dev.perl.org/licenses/ for more information.
+
+
+=cut
+
