@@ -8,7 +8,9 @@ use Archive::Har::Entry::Response();
 use Archive::Har::Entry::Cache();
 use Archive::Har::Entry::Timings();
 
-our $VERSION = '0.11';
+our $VERSION = 0.12;
+
+sub _DOES_NOT_APPLY { return -1 }
 
 sub new {
     my ( $class, $params ) = @_;
@@ -101,7 +103,7 @@ sub time {
         return $total;
     }
     else {
-        return -1;
+        return _DOES_NOT_APPLY();
     }
 }
 
@@ -252,7 +254,9 @@ Archive::Har::Entry - Represents a single http request/response pair inside the
 
 =head1 VERSION
 
-Version '0.11'
+Version 0.12
+
+=for stopwords HAR pageref IP DNS perldoc CPAN AnnoCPAN 
 
 =head1 SYNOPSIS
 
@@ -272,8 +276,14 @@ Version '0.11'
         print "Server IP Address: " . $entry->server_ip_address() . "\n";
         print "Connection: " . $entry->connection() . "\n";
         print "Comment: " . $entry->comment() . "\n";
+        $entry->comment("Something interesting here");
     }
 
+=head1 DESCRIPTION
+ 
+This Module is intended to provide an interface to create/read/update
+Entry objects in HTTP Archive (HAR) files.
+
 =head1 SUBROUTINES/METHODS
 
 =head2 new
@@ -282,7 +292,7 @@ returns a new Entry object
 
 =head2 pageref
 
-returns the reference to the parent page.  This may be null.
+returns the L<reference|Archive::Har::Page/"id"> to the parent L<page|Archive::Har::Page>.  This may be null.
 
 =head2 started_date_time
 
@@ -320,3 +330,54 @@ returns the unique ID of the parent TCP/IP connection.  This can be the client p
 
 returns the comment about the Entry
 
+=head1 DIAGNOSTICS
+
+=over
+
+=item C<< started_date_time is not formatted correctly >>
+
+The started_date_time field must be formatted like so
+
+0000-00-00T00:00:00.0+00:00
+
+=item C<< %s is not specified in the HAR 1.2 spec and does not start with an underscore >>
+
+The HAR 1.2 specification allows undocumented fields, but they must start with an underscore
+
+=back
+
+=head1 CONFIGURATION AND ENVIRONMENT
+
+Archive::Har::Entry requires no configuration files or environment variables.  
+
+=head1 DEPENDENCIES
+
+Archive::Har::Entry requires no additional non-core Perl modules
+
+=head1 INCOMPATIBILITIES
+
+None reported
+
+=head1 AUTHOR
+
+David Dick, C<< <ddick at cpan.org> >>
+
+=head1 BUGS AND LIMITATIONS
+
+Please report any bugs or feature requests to C<bug-archive-har at rt.cpan.org>, or through
+the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Archive-Har>.  I will be notified, and then you'll
+automatically be notified of progress on your bug as I make changes.
+
+=head1 LICENSE AND COPYRIGHT
+
+Copyright 2015 David Dick.
+
+This program is free software; you can redistribute it and/or modify it
+under the terms of either: the GNU General Public License as published
+by the Free Software Foundation; or the Artistic License.
+
+See http://dev.perl.org/licenses/ for more information.
+
+
+=cut
+
