@@ -4,7 +4,9 @@ use warnings;
 use strict;
 use Carp();
 
-our $VERSION = '0.11';
+our $VERSION = 0.12;
+
+sub _DOES_NOT_APPLY { return -1 }
 
 sub new {
     my ( $class, $params ) = @_;
@@ -38,10 +40,10 @@ sub on_content_load {
             }
         }
         else {
-            $self->{onContentLoad} = -1;
+            $self->{onContentLoad} = _DOES_NOT_APPLY();
         }
     }
-    if ( ( defined $old ) && ( $old == -1 ) ) {
+    if ( ( defined $old ) && ( $old == _DOES_NOT_APPLY() ) ) {
         return;
     }
     else {
@@ -62,10 +64,10 @@ sub on_load {
             }
         }
         else {
-            $self->{onLoad} = -1;
+            $self->{onLoad} = _DOES_NOT_APPLY();
         }
     }
-    if ( ( defined $old ) && ( $old == -1 ) ) {
+    if ( ( defined $old ) && ( $old == _DOES_NOT_APPLY() ) ) {
         return;
     }
     else {
@@ -110,13 +112,13 @@ sub TO_JSON {
         $json->{onContentLoad} = $self->on_content_load();
     }
     else {
-        $json->{onContentLoad} = -1;
+        $json->{onContentLoad} = _DOES_NOT_APPLY();
     }
     if ( defined $self->on_load() ) {
         $json->{onLoad} = $self->on_load();
     }
     else {
-        $json->{onLoad} = -1;
+        $json->{onLoad} = _DOES_NOT_APPLY();
     }
     if ( defined $self->comment() ) {
         $json->{comment} = $self->comment();
@@ -138,7 +140,9 @@ Archive::Har::Page::PageTimings - Represents detailed timing of page within the
 
 =head1 VERSION
 
-Version '0.11'
+Version 0.12
+
+=for stopwords HAR PageTimings undef
 
 =head1 SYNOPSIS
 
@@ -154,6 +158,11 @@ Version '0.11'
         print "Comment for " . $page->title() . ": " . $timings->comment() . "\n";
     }
 
+=head1 DESCRIPTION
+ 
+This Module is intended to provide an interface to create/read/update
+PageTimings objects in HTTP Archive (HAR) files.
+
 =head1 SUBROUTINES/METHODS
 
 =head2 new
@@ -162,13 +171,66 @@ returns a new PageTimings object
 
 =head2 on_content_load
 
-returns the number of milliseconds since $har->page()->startedDateTime() that the content of the page loaded or undef if the timing does not apply
+returns the number of milliseconds since L<$har-E<gt>page()-E<gt>started_date_time()|Archive::Har::Page/"started_date_time"> that the content of the page loaded or undef if the timing does not apply
 
 =head2 on_load
 
-returns the number of milliseconds since $har->page()->startedDateTime() that the page loaded or undef if the timing does not apply
+returns the number of milliseconds since L<$har-E<gt>page()-E<gt>started_date_time()|Archive::Har::Page/"started_date_time"> that the page loaded or undef if the timing does not apply
 
 =head2 comment
 
 returns the comment about the page timing
 
+=head1 DIAGNOSTICS
+
+=over
+
+=item C<< on_content_load must be a positive number or -1 >>
+
+This field is measured as a number of milliseconds
+
+=item C<< on_load must be a positive number or -1 >>
+
+This field is measured as a number of milliseconds
+
+=item C<< %s is not specified in the HAR 1.2 spec and does not start with an underscore >>
+
+The HAR 1.2 specification allows undocumented fields, but they must start with an underscore
+
+=back
+
+=head1 CONFIGURATION AND ENVIRONMENT
+
+Archive::Har::Page::PageTimings requires no configuration files or environment variables.  
+
+=head1 DEPENDENCIES
+
+Archive::Har::Page::PageTimings requires no additional non-core Perl modules
+
+=head1 INCOMPATIBILITIES
+
+None reported
+
+=head1 AUTHOR
+
+David Dick, C<< <ddick at cpan.org> >>
+
+=head1 BUGS AND LIMITATIONS
+
+Please report any bugs or feature requests to C<bug-archive-har at rt.cpan.org>, or through
+the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Archive-Har>.  I will be notified, and then you'll
+automatically be notified of progress on your bug as I make changes.
+
+=head1 LICENSE AND COPYRIGHT
+
+Copyright 2015 David Dick.
+
+This program is free software; you can redistribute it and/or modify it
+under the terms of either: the GNU General Public License as published
+by the Free Software Foundation; or the Artistic License.
+
+See http://dev.perl.org/licenses/ for more information.
+
+
+=cut
+
